<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define( 'THEMEROOT', get_stylesheet_directory_uri() );
define( 'IMAGES', THEMEROOT . '/images' );
define( 'SCRIPTS', THEMEROOT . '/js' );
require_once( 'wp_bootstrap_navwalker.php' );


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if ( ! function_exists( 'alpha_setup' ) ) {
	function alpha_setup() {
		/**
		 * Make the theme available for translation.
		 */
		$lang_dir = THEMEROOT . '/languages';
		load_theme_textdomain( 'alpha', $lang_dir );

		/**
		 * Add support for post formats.
		 */
//		add_theme_support( 'post-formats',
//			array(
//				'gallery',
//				'link',
//				'image',
//				'quote',
//				'video',
//				'audio'
//			)
//		);

		/**
		 * Add support for automatic feed links.
		 */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'widgets' );

		/**
		 * Add support for post thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );


		/**
		 * Register nav menus.
		 */
		register_nav_menus(
			array(
				'main-menu' => __( 'القائمة الرئيسية', 'alpha' ),
				'footer'    => __( 'قائمة الفوتر ', 'alpha' )
			)
		);
	}

	add_action( 'after_setup_theme', 'alpha_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'alpha_scripts' ) ) {
	function alpha_scripts() {
		// Adds support for pages with threaded comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register scripts
		wp_register_script( 'bootstrap-js', SCRIPTS . '/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'classie', SCRIPTS . '/classie.js', array( 'jquery' ), false, true );
//		wp_register_script( 'ticker', SCRIPTS . '/jquery.ticker.js', array( 'jquery' ), false, true );
//		wp_register_script( 'modernizr', SCRIPTS . '/modernizr.custom.97074.js', array( 'jquery' ), false, true );
//		wp_register_script( 'owlcarousel', SCRIPTS . '/owl.carousel.min.js', array( 'jquery' ), false, true );
//		wp_register_script( 'wow', SCRIPTS . '/wow.min.js', array( 'jquery' ), false, true );


		// Load the custom scripts
		wp_enqueue_script( 'bootstrap-js' );
		wp_enqueue_script( 'classie' );
//		wp_enqueue_script( 'ticker' );
//		wp_enqueue_script( 'modernizr' );
//		wp_enqueue_script( 'owlcarousel' );
//		wp_enqueue_script( 'wow' );


		wp_register_script( 'custom', SCRIPTS . '/custom.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'custom' );


		// Load the stylesheets
		wp_enqueue_style( 'bootstrap', THEMEROOT . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'Fontawesome', THEMEROOT . '/css/font-awesome.min.css' );
		wp_enqueue_style( 'sin', THEMEROOT . '/css/sinister.css' );
//		wp_enqueue_style( 'animate', THEMEROOT . '/css/animate.css' );
//		wp_enqueue_style( 'owl.carousel', THEMEROOT . '/css/owl.carousel.css' );

		if ( is_rtl() ) {

			wp_enqueue_style( 'bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.min.css' );
			wp_enqueue_style( 'rtl', THEMEROOT . '/style.css' );

		} else {
			wp_enqueue_style( 'en', THEMEROOT . '/en.css' );
		}

	}

	add_action( 'wp_enqueue_scripts', 'alpha_scripts' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */
//register_post_type( 'c-fields', array(
//	'public'              => true,
//	'hierarchical'        => false,
//	'exclude_from_search' => false,
//	'has_archive'         => false,
//	'rewrite'             => array( 'slug' => 'c-fields' ),
//	'capability_type'     => 'post',
//	'taxonomies'          => array( 'post_tag' ),
//	'labels'              => array(
//		'name'               => 'المجالات',
//		'add_new_item'       => 'إضافة ',
//		'singular_name'      => 'المجالات',
//		'menu_name'          => 'المجالات',
//		'name_admin_bar'     => 'المجالات',
//		'all_items'          => 'الكل',
//		'add_new'            => 'إضافة ',
//		'edit_item'          => 'تحرير ',
//		'new_item'           => ' جديد',
//		'view_item'          => 'مشاهدة ',
//		'search_items'       => 'البحث ',
//		'not_found'          => 'لا يوجد .',
//		'not_found_in_trash' => 'لا يوجد ',
//		'parent_item_colon'  => 'القسم الرئيسى'
//	),
//	'supports'            => array( 'title', 'thumbnail', 'editor' )
//) );


/*************************************************/
/* Sidebar */
/*************************************************/
if ( function_exists( 'register_sidebar' ) ) {
	register_sidebar(
		array(
			'name'          => 'single post sidebar',
			'id'            => 'sidebar',
			'description'   => 'single post Sidebar',
			'before_widget' => '<div class="rest-of-news">',
			'after_widget'  => '</div>',
			'before_title'  => '<h1 class="box-section-title">',
			'after_title'   => '</h1>'

		)
	);
}
if ( function_exists( 'register_sidebar' ) ) {
	register_sidebar(
		array(
			'name'          => 'categories sidebar ',
			'id'            => 'catsidebar',
			'description'   => 'Categories Sidebar',
			'before_widget' => '<div class="rest-of-news">',
			'after_widget'  => '</div>',
			'before_title'  => '<h1 class="box-section-title">',
			'after_title'   => '</h1>'

		)
	);
}
add_image_size( 'small', 100, 100 );


/*************************************************/
/* Page Option */
/*************************************************/
if ( function_exists( 'acf_add_options_page' ) ) {

	acf_add_options_page( array(
		'page_title'    => 'اعدادات القالب',
		'menu_title'    => 'اعدادات القالب',
		'menu_slug'     => 'theme-general-settings',
		'capability'    => 'manage_options',
		'update_button' => 'حفظ الاعدادات',
		'redirect'      => false
	) );

}
if ( is_super_admin() ) {
	function mytheme_admin_bar_render() {
		global $wp_admin_bar;
		$wp_admin_bar->add_menu( array(
			'id'    => 'themeoptions',
			'title' => '<i class="options-icon"></i>' . __( 'اعدادات القالب', 'some-textdomain' ),
			'href'  => admin_url( 'admin.php?page=theme-general-settings' ),
			'icon'  => 'img'
		) );

	}
	// and we hook our function via
	add_action( 'wp_before_admin_bar_render', 'mytheme_admin_bar_render' );
}


$user = wp_get_current_user();
if ( in_array( 'contributor', (array) $user->roles ) ) {
	function custom_menu_page_removing() {
		remove_menu_page( 'tools.php' );
		remove_menu_page( 'wpcf7' );
		remove_menu_page( 'edit-comments.php' );
//		remove_menu_page( 'acf-theme-general-settings' );
	}

	add_action( 'admin_menu', 'custom_menu_page_removing' );
}